@@ -90,6 +90,12 @@ int foc_device_init(FAR struct foc_device_s *dev, int id)
       goto errout;
     }
 
+#ifdef CONFIG_EXAMPLES_FOC_PERF
+  /* Initialize perf */
+
+  foc_perf_init(&dev->perf);
+#endif
+
 errout:
   return ret;
 }
@@ -172,6 +178,10 @@ int foc_dev_state_get(FAR struct foc_device_s *dev)
       goto errout;
     }
 
+#ifdef CONFIG_EXAMPLES_FOC_PERF
+  foc_perf_start(&dev->perf);
+#endif
+
 errout:
   return ret;
 }
@@ -195,6 +205,10 @@ int foc_dev_params_set(FAR struct foc_device_s *dev)
       goto errout;
     }
 
+#ifdef CONFIG_EXAMPLES_FOC_PERF
+  foc_perf_end(&dev->perf);
+#endif
+
 errout:
   return ret;
 }
