@@ -30,6 +30,7 @@
 #include <pthread.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <math.h>
 
 #ifdef CONFIG_EXAMPLES_NXSCOPE_TIMER
 #  include <sys/ioctl.h>
@@ -41,6 +42,16 @@
 
 #include "logging/nxscope/nxscope.h"
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+#ifdef CONFIG_LIBM_NONE
+#  error "math library must be selected for this example"
+#endif
+
+#define SIN_DT (0.01f)
+
 /****************************************************************************
  * Private Type Definition
  ****************************************************************************/
@@ -197,14 +208,14 @@ static FAR void *nxscope_samples_thr(FAR void *arg)
   sigaddset(&set, CONFIG_EXAMPLES_NXSCOPE_TIMER_SIGNO);
 #endif
 
-  /* Initialize float vector */
-
-  v[0] = -1.0f;
-  v[1] = 0.0f;
-  v[2] = 1.0f;
-
   while (1)
     {
+      /* Float vector - tree-phase sine waveform */
+
+      v[0] = sinf(i * SIN_DT);
+      v[1] = sinf(i * SIN_DT + (2.0f / 3.0f) * M_PI);
+      v[2] = sinf(i * SIN_DT + (4.0f / 3.0f) * M_PI);
+
       /* Channel 0 */
 
       nxscope_put_uint8(envp->nxs, 0, i);
@@ -309,6 +320,7 @@ errout:
   return NULL;
 }
 
+#ifdef CONFIG_EXAMPLES_NXSCOPE_CHARLOG
 /****************************************************************************
  * Name: nxscope_charlog_thr
  ****************************************************************************/
@@ -336,6 +348,7 @@ static FAR void *nxscope_charlog_thr(FAR void *arg)
 
   return NULL;
 }
+#endif
 
 #ifdef CONFIG_LOGGING_NXSCOPE_CRICHANNELS
 /****************************************************************************
@@ -621,12 +634,14 @@ int main(int argc, FAR char *argv[])
   u.s.cri   = 0;
   nxscope_chan_init(&nxs, 18, "chan18", u.u8, 0, 4);
 
+#ifdef CONFIG_EXAMPLES_NXSCOPE_CHARLOG
   /* Char channel with metadata */
 
   u.s.dtype = NXSCOPE_TYPE_CHAR;
   u.s._res  = 0;
   u.s.cri   = 0;
   nxscope_chan_init(&nxs, 19, "chan19", u.u8, 64, 4);
+#endif
 
 #ifdef CONFIG_LOGGING_NXSCOPE_CRICHANNELS
   /* Critical channel */
@@ -649,6 +664,7 @@ int main(int argc, FAR char *argv[])
       goto errout;
     }
 
+#ifdef CONFIG_EXAMPLES_NXSCOPE_CHARLOG
   /* Create char log thread */
 
   env.nxs = &nxs;
@@ -658,6 +674,7 @@ int main(int argc, FAR char *argv[])
       printf("ERROR: pthread_create failed %d\n", ret);
       goto errout;
     }
+#endif
 
 #ifdef CONFIG_LOGGING_NXSCOPE_CRICHANNELS
   /* Create critical channel thread */
@@ -698,7 +715,7 @@ int main(int argc, FAR char *argv[])
           printf("ERROR: nxscope_recv failed %d\n", ret);
         }
 
-      usleep(100000);
+      usleep(CONFIG_EXAMPLES_NXSCOPE_MAIN_INTERVAL);
     }
 
 errout:
