@@ -587,7 +587,7 @@ void telnet_begin_compress2(struct telnet_s *telnet);
  ****************************************************************************/
 
 int telnet_printf(struct telnet_s *telnet, const char *fmt, ...)
-    printflike(2, 3);
+    printf_like(2, 3);
 
 /****************************************************************************
  * Name: telnet_vprintf
@@ -600,7 +600,7 @@ int telnet_printf(struct telnet_s *telnet, const char *fmt, ...)
  ****************************************************************************/
 
 int telnet_vprintf(struct telnet_s *telnet, const char *fmt, va_list va)
-    printflike(2, 0);
+    printf_like(2, 0);
 
 /****************************************************************************
  * Name: telnet_raw_printf
@@ -622,7 +622,7 @@ int telnet_vprintf(struct telnet_s *telnet, const char *fmt, va_list va)
  ****************************************************************************/
 
 int telnet_raw_printf(struct telnet_s *telnet, const char *fmt, ...)
-    printflike(2, 3);
+    printf_like(2, 3);
 
 /****************************************************************************
  * Name: telnet_raw_vprintf
@@ -635,7 +635,7 @@ int telnet_raw_printf(struct telnet_s *telnet, const char *fmt, ...)
  ****************************************************************************/
 
 int telnet_raw_vprintf(struct telnet_s *telnet, const char *fmt, va_list va)
-    printflike(2, 0);
+    printf_like(2, 0);
 
 /****************************************************************************
  * Name: telnet_begin_newenviron
