@@ -34,10 +34,13 @@
 #define TOYWASM_USE_LOCALTYPE_CELLIDX
 #define TOYWASM_ENABLE_WRITER
 #define TOYWASM_ENABLE_WASM_SIMD
+#define TOYWASM_ENABLE_WASM_EXCEPTION_HANDLING
+#define TOYWASM_EXCEPTION_MAX_CELLS 4
 #define TOYWASM_ENABLE_WASM_EXTENDED_CONST
 #define TOYWASM_ENABLE_WASM_MULTI_MEMORY
 #define TOYWASM_ENABLE_WASM_TAILCALL
 #define TOYWASM_ENABLE_WASM_THREADS
+#define TOYWASM_ENABLE_WASM_NAME_SECTION
 #define TOYWASM_ENABLE_WASI
 #define TOYWASM_ENABLE_WASI_THREADS
 #define TOYWASM_ENABLE_DYLD
