@@ -26,6 +26,7 @@
 
 #include <string.h>
 #include <assert.h>
+#include <stdlib.h>
 
 #ifdef CONFIG_NSH_BUILTIN_APPS
 #  include <nuttx/lib/builtin.h>
@@ -91,6 +92,10 @@ static int  cmd_false(FAR struct nsh_vtbl_s *vtbl, int argc,
 static int  cmd_exit(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv);
 #endif
 
+#ifndef CONFIG_NSH_DISABLE_EXPR
+static int cmd_expr(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv);
+#endif
+
 static int  cmd_unrecognized(FAR struct nsh_vtbl_s *vtbl, int argc,
                              FAR char **argv);
 
@@ -164,7 +169,7 @@ static const struct cmdmap_s g_cmdmap[] =
 #endif
 
 #ifndef CONFIG_NSH_DISABLE_CP
-  CMD_MAP("cp",       cmd_cp,       3, 3, "<source-path> <dest-path>"),
+  CMD_MAP("cp",       cmd_cp,       3, 4, "[-r] <source-path> <dest-path>"),
 #endif
 
 #ifndef CONFIG_NSH_DISABLE_CMP
@@ -177,13 +182,13 @@ static const struct cmdmap_s g_cmdmap[] =
 
 #ifndef CONFIG_NSH_DISABLE_DATE
   CMD_MAP("date",     cmd_date,
-          1, 4, "[-s \"MMM DD HH:MM:SS YYYY\"] [-u]"),
+          1, 4, "[-s \"MMM DD HH:MM:SS YYYY\"] [-u] [+format]"),
 #endif
 
 #ifndef CONFIG_NSH_DISABLE_DD
   CMD_MAP("dd",       cmd_dd,       3, 7,
     "if=<infile> of=<outfile> [bs=<sectsize>] [count=<sectors>] "
-    "[skip=<sectors>] [verify]"),
+    "[skip=<sectors>] [seek=<sectors>] [verify]"),
 #endif
 
 #if defined(CONFIG_NET) && defined(CONFIG_NET_ROUTE) && !defined(CONFIG_NSH_DISABLE_DELROUTE)
@@ -226,6 +231,11 @@ static const struct cmdmap_s g_cmdmap[] =
   CMD_MAP("exit",     cmd_exit,     1, 1, NULL),
 #endif
 
+#ifndef CONFIG_NSH_DISABLE_EXPR
+  CMD_MAP("expr",     cmd_expr,     4, 4,
+    "<operand1> <operator> <operand2>"),
+#endif
+
 #ifndef CONFIG_NSH_DISABLE_EXPORT
   CMD_MAP("export",   cmd_export,   2, 3, "[<name> [<value>]]"),
 #endif
@@ -513,8 +523,14 @@ static const struct cmdmap_s g_cmdmap[] =
 #endif
 #endif
 
+#if defined(CONFIG_RPMSG) && !defined(CONFIG_NSH_DISABLE_RPMSG)
+  CMD_MAP("rpmsg",    cmd_rpmsg,    2, 7,
+    "<panic|dump|ping> <path|all>"
+    " [value|times length ack sleep]"),
+#endif
+
 #if defined(CONFIG_RPTUN) && !defined(CONFIG_NSH_DISABLE_RPTUN)
-  CMD_MAP("rptun",    cmd_rptun,    3, 7,
+  CMD_MAP("rptun",    cmd_rptun,    2, 7,
     "<start|stop|reset|panic|dump|ping> <path|all>"
     " [value|times length ack sleep]"),
 #endif
@@ -1091,6 +1107,74 @@ static int cmd_exit(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 }
 #endif
 
+#ifndef CONFIG_NSH_DISABLE_EXPR
+static int cmd_expr(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
+{
+  int operand1;
+  int operand2;
+  int result;
+  FAR char *endptr;
+
+  if (argc != 4)
+    {
+      nsh_output(vtbl, "Usage: %s <operand1> <operator> <operand2>\n",
+                 argv[0]);
+      return ERROR;
+    }
+
+  operand1 = strtol(argv[1], &endptr, 0);
+  if (*endptr != '\0')
+    {
+      nsh_output(vtbl, "operand1 invalid\n");
+      return ERROR;
+    }
+
+  operand2 = strtol(argv[3], &endptr, 0);
+  if (*endptr != '\0')
+    {
+      nsh_output(vtbl, "operand2 invalid\n");
+      return ERROR;
+    }
+
+  switch (argv[2][0])
+    {
+      case '+':
+        result = operand1 + operand2;
+        break;
+      case '-':
+        result = operand1 - operand2;
+        break;
+      case '*':
+        result = operand1 * operand2;
+        break;
+      case '/':
+        if (operand2 == 0)
+          {
+            nsh_output(vtbl, "operand2 invalid\n");
+            return ERROR;
+          }
+
+        result = operand1 / operand2;
+        break;
+      case '%':
+        if (operand2 == 0)
+          {
+            nsh_output(vtbl, "operand2 invalid\n");
+            return ERROR;
+          }
+
+        result = operand1 % operand2;
+        break;
+      default:
+        nsh_output(vtbl, "Unknown operator\n");
+        return ERROR;
+    }
+
+  nsh_output(vtbl, "%d\n", result);
+  return OK;
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
