@@ -31,6 +31,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/ioctl.h>
+#include <sys/param.h>
 #include <unistd.h>
 
 #include <nuttx/sensors/sensor.h>
@@ -39,7 +40,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define ARRAYSIZE(a)       (sizeof(a) / sizeof(a)[0])
 #define DEVNAME_FMT        "/dev/uorb/sensor_%s"
 #define DEVNAME_MAX        64
 
@@ -67,6 +67,7 @@ static void print_valf(FAR const char *buffer, FAR const char *name);
 static void print_valb(FAR const char *buffer, FAR const char *name);
 static void print_vali2(FAR const char *buffer, FAR const char *name);
 static void print_ecg(FAR const char *buffer, FAR const char *name);
+static void print_force(FAR const char *buffer, FAR const char *name);
 static void print_ppgd(FAR const char *buffer, FAR const char *name);
 static void print_ppgq(FAR const char *buffer, FAR const char *name);
 static void print_cap(FAR const char *buffer, FAR const char *name);
@@ -88,6 +89,7 @@ static const struct sensor_info g_sensor_info[] =
   {print_valf,  sizeof(struct sensor_co2),   "co2"},
   {print_valf,  sizeof(struct sensor_dust),  "dust"},
   {print_ecg,   sizeof(struct sensor_ecg),   "ecg"},
+  {print_force, sizeof(struct sensor_force), "force"},
   {print_gps,   sizeof(struct sensor_gps),   "gps"},
   {print_gps_satellite,
         sizeof(struct sensor_gps_satellite), "gps_satellite"},
@@ -171,6 +173,14 @@ static void print_ecg(const char *buffer, const char *name)
          name, event->timestamp, event->ecg, event->status);
 }
 
+static void print_force(const char *buffer, const char *name)
+{
+  FAR struct sensor_force *event = (FAR struct sensor_force *)buffer;
+
+  printf("%s: timestamp:%" PRIu64 " value:%.2f event:%" PRIi32 "\n",
+         name, event->timestamp, event->force, event->event);
+}
+
 static void print_ppgd(const char *buffer, const char *name)
 {
   FAR struct sensor_ppgd *event = (FAR struct sensor_ppgd *)buffer;
@@ -307,7 +317,7 @@ int main(int argc, FAR char *argv[])
   if (optind < argc)
     {
       name = argv[optind];
-      for (idx = 0; idx < ARRAYSIZE(g_sensor_info); idx++)
+      for (idx = 0; idx < nitems(g_sensor_info); idx++)
         {
           if (!strncmp(name, g_sensor_info[idx].name,
               strlen(g_sensor_info[idx].name)))
