@@ -22,6 +22,7 @@
  * Included Files
  ****************************************************************************/
 
+#include <sys/param.h>
 #include <sys/socket.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -94,8 +95,6 @@ static const struct iwpan_command_s g_iwpan_commands[] =
   {"txpwr",   2, (CODE void *)iwpan_txpwr_cmd},
 };
 
-#define NCOMMANDS (sizeof(g_iwpan_commands) / sizeof(struct iwpan_command_s))
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -660,7 +659,7 @@ int main(int argc, FAR char *argv[])
   /* Find the command in the g_iwpan_command[] list */
 
   iwpancmd = NULL;
-  for (i = 0; i < NCOMMANDS; i++)
+  for (i = 0; i < nitems(g_iwpan_commands); i++)
     {
       FAR const struct iwpan_command_s *cmd = &g_iwpan_commands[i];
       if (strcmp(cmdname, cmd->name) == 0)
